@@ -1,5 +1,31 @@
 #!/bin/sh
 
+
+list_alternatives() {
+cat <<EOF
+gem-plugin-glfw3	70 gemdefaultwindow.pd gemdefaultwindow-glfw3.pd
+gem-plugin-sdl		70 gemdefaultwindow.pd gemdefaultwindow-sdl.pd
+gem-plugin-glut		70 gemdefaultwindow.pd gemdefaultwindow-glut.pd
+gem			50 gemdefaultwindow.pd gemdefaultwindow-glx.pd
+EOF
+}
+
+build_alternatives () {
+list_alternatives  | while read pkg prio name alt; do
+  cat > debian/${pkg}.alternatives <<EOF
+Name: ${name}
+Link: /usr/lib/pd/extra/Gem/${name}
+Alternative: /usr/lib/pd/extra/Gem/${alt}
+Priority: ${prio}
+EOF
+done
+}
+
+#build_alternatives; exit $?
+
+echo "NOTE: with dh>=13.1 there's a new dh_installalternatives" 1>&2
+echo "see $0 for more info" 1>&2
+
 INFILE=debian/alternatives
 BASEDIR=/usr/lib/pd/extra/Gem
 DOLLAR1='$1'
